@@ -1082,7 +1082,8 @@ class Witter():
 	    self.newTweet(self, widget, *args)
 	    #if we were in the search view, we want to restore the search terms after a tweet
 	    if (self.treeview.get_model() == self.searchliststore):
-		self.tweetText.set_text(self.search_terms)
+		    self.tweetText.set_text(self.search_terms)
+
 
 
     def newTweet(self, widget, *args):
@@ -1110,6 +1111,7 @@ class Witter():
                 self.reply_to_name = None
                 self.reply_to = None
                 #last thing to do is refresh main feed
+                self.tweetText.set_text("")
                 self.getTweets()
             except IOError, e:
                 msg = 'Error posting tweet '
@@ -1164,21 +1166,22 @@ class Witter():
             opener = urllib2.build_opener(auth_handler)
             # ...and install it globally so it can be used with urlopen.
     	    try:
-        		urllib2.install_opener(opener)
-        		json = urllib2.urlopen(req)
+                urllib2.install_opener(opener)
+                json = urllib2.urlopen(req)
         		#opener.close()
-        		data = simplejson.loads(json.read())
+                data = simplejson.loads(json.read())
         		#message sent, I'm assuming a failure to send would not continue
         		#in this method? so it's safe to remove the tweet line
         		# what I don't want is to lose the tweet I typed if we didn't
         		# sucessfully send it to twitter. that would be annoying (I'm looking
         		# at you Mauku)
-        		self.builder.get_object("TweetText").set_text("")
-        		hildon.hildon_banner_show_information(self.window, "", "Tweet Successful")
-        		self.reply_to_name = None
-        		self.reply_to = None
+                self.builder.get_object("TweetText").set_text("")
+                hildon.hildon_banner_show_information(self.window, "", "Tweet Successful")
+                self.reply_to_name = None
+                self.reply_to = None
         		#last thing to do is refresh main feed
-        		self.getTweets()
+                self.tweetText.set_text("")
+                self.getTweets()
     	    except IOError, e:
                 msg = 'Error posting tweet '
                 if hasattr(e, 'reason'):
